window.Gleam.initSearch([{"doc":"midas_node","title":"midas_node","content":"# midas_node\n\nRun [midas](https://github.com/midas-framework/midas) tasks on nodejs.\nmidas_node supports all of the defined effects in the latest version of the midas library.\n\n[![Package Version](https://img.shields.io/hexpm/v/midas_node)](https://hex.pm/packages/midas_node)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/midas_node/)\n\n## Dependencies\n\nInstall the required dependencies for the node environment as well as the gleam dependency\n\n```sh\nnpm install --save @zip.js/zip.js rollup @rollup/plugin-node-resolve chokidar\ngleam add midas_node\n```\n\n## Run a task once\n\nUse `node.run` with a task and root position in the file system.\nAll calls to `Read` `Write` or `List` (contents of a directory) are relative to this path.\n\n```gleam\nimport midas/node\n\npub fn main() {\n  let task = // a midas task\n  node.run(task, &quot;/root&quot;)\n}\n```\n\n## Watch a task\n\nUse `node.watch` to run a task and the rerun it when required in response to changes on the filesystem.\nSee the following example in the [example](./example) directory.\n\n```gleam\nimport midas/node\n\n// print the reason for a task failing\nfn callback(result) {\n  case result {\n    Ok(Nil) -&gt; Nil\n    Error(reason) -&gt; io.println(snag.pretty_print(reason))\n  }\n}\n\npub fn main() {\n  let task = {\n    use src &lt;- t.do(t.bundle(&quot;example/client&quot;, &quot;run&quot;))\n    use page &lt;- t.do(t.read(&quot;src/index.html&quot;))\n    t.done([#(&quot;/&quot;, page), #(&quot;/main.js&quot;, &lt;&lt;src:utf8&gt;&gt;)])\n  }\n  node.watch(task, &quot;/root&quot;, callback)\n}\n```\n\n**Note: watch is lazy**, and will only rerun the task from the point where a file has changed.\nIn the previous example if `index.html` is changed then the project will not be rebundled.\nThis makes watch more responsive. To get the most out response watch pipeline put slow tasks earlier in the task.\n(asynchrony is coming soon to make things even faster but the API is still being finalised)\n\nThe result of calls to HTTP fetch are assumed unchanged so will be rerun if only a previous files value has changed.\n\nFurther documentation can be found at &lt;https://hexdocs.pm/midas_node&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"midas/js/run","title":"Run","content":"pub type Run(a) =\n  Promise(Result(a, String))\n\n\nSynonyms:\nmidas/js/run.Run\nmidas/js/run Run","url":"midas/js/run.html#Run"},{"doc":"midas/js/run","title":"await","content":"pub fn await(\n  p: Promise(Result(a, b)),\n  then: fn(a) -&gt; Promise(Result(c, b)),\n) -&gt; Promise(Result(c, b))\n\nSynonyms:\nmidas/js/run.await\nmidas/js/run await","url":"midas/js/run.html#await"},{"doc":"midas/js/run","title":"done","content":"pub fn done(value: a) -&gt; Promise(Result(a, b))\n\nSynonyms:\nmidas/js/run.done\nmidas/js/run done","url":"midas/js/run.html#done"},{"doc":"midas/js/run","title":"fail","content":"pub fn fail(reason: a) -&gt; Promise(Result(b, a))\n\nSynonyms:\nmidas/js/run.fail\nmidas/js/run fail","url":"midas/js/run.html#fail"},{"doc":"midas/js/run","title":"map_error","content":"pub fn map_error(\n  p: Promise(Result(a, b)),\n  f: fn(b) -&gt; c,\n) -&gt; Promise(Result(a, c))\n\nSynonyms:\nmidas/js/run.map_error\nmidas/js/run map_error","url":"midas/js/run.html#map_error"},{"doc":"midas/js/run","title":"try","content":"pub fn try(\n  result: Result(a, b),\n  then: fn(a) -&gt; Promise(Result(c, b)),\n) -&gt; Promise(Result(c, b))\n\nSynonyms:\nmidas/js/run.try\nmidas/js/run try","url":"midas/js/run.html#try"},{"doc":"midas/js/run","title":"midas/js/run","content":"","url":"midas/js/run.html"},{"doc":"midas/node/browser","title":"open","content":"pub fn open(url: a) -&gt; ChildProcess\n\nSynonyms:\nmidas/node/browser.open\nmidas/node/browser open","url":"midas/node/browser.html#open"},{"doc":"midas/node/browser","title":"midas/node/browser","content":"","url":"midas/node/browser.html"},{"doc":"midas/node/chokidar","title":"AllEvent","content":"pub type AllEvent {\n  Add\n  Change\n  Unlink\n  AddDir\n  UnlinkDir\n}\n\nAdd\n\n\nChange\n\n\nUnlink\n\n\nAddDir\n\n\nUnlinkDir\n\n\nSynonyms:\nmidas/node/chokidar.AllEvent\nmidas/node/chokidar AllEvent","url":"midas/node/chokidar.html#AllEvent"},{"doc":"midas/node/chokidar","title":"FsWatcher","content":"pub type FsWatcher\n\n\nSynonyms:\nmidas/node/chokidar.FsWatcher\nmidas/node/chokidar FsWatcher","url":"midas/node/chokidar.html#FsWatcher"},{"doc":"midas/node/chokidar","title":"on_all","content":"pub fn on_all(\n  watcher: FsWatcher,\n  callback f: fn(AllEvent, String) -&gt; Nil,\n) -&gt; Nil\n\nSynonyms:\nmidas/node/chokidar.on_all\nmidas/node/chokidar on_all","url":"midas/node/chokidar.html#on_all"},{"doc":"midas/node/chokidar","title":"watch","content":"pub fn watch(initial: List(String)) -&gt; FsWatcher\n\nSynonyms:\nmidas/node/chokidar.watch\nmidas/node/chokidar watch","url":"midas/node/chokidar.html#watch"},{"doc":"midas/node/chokidar","title":"midas/node/chokidar","content":"","url":"midas/node/chokidar.html"},{"doc":"midas/node/file_system","title":"create_directory_all","content":"pub fn create_directory_all(dir: String) -&gt; Result(Nil, Snag)\n\nSynonyms:\nmidas/node/file_system.create_directory_all\nmidas/node/file_system create_directory_all","url":"midas/node/file_system.html#create_directory_all"},{"doc":"midas/node/file_system","title":"current_directory","content":"pub fn current_directory() -&gt; Result(String, Snag)\n\nSynonyms:\nmidas/node/file_system.current_directory\nmidas/node/file_system current_directory","url":"midas/node/file_system.html#current_directory"},{"doc":"midas/node/file_system","title":"get_files","content":"pub fn get_files(dir: String) -&gt; Result(List(String), Snag)\n\nSynonyms:\nmidas/node/file_system.get_files\nmidas/node/file_system get_files","url":"midas/node/file_system.html#get_files"},{"doc":"midas/node/file_system","title":"read","content":"pub fn read(filename: String) -&gt; Result(BitArray, Snag)\n\nSynonyms:\nmidas/node/file_system.read\nmidas/node/file_system read","url":"midas/node/file_system.html#read"},{"doc":"midas/node/file_system","title":"read_directory","content":"pub fn read_directory(dir: String) -&gt; Result(List(String), Snag)\n\nSynonyms:\nmidas/node/file_system.read_directory\nmidas/node/file_system read_directory","url":"midas/node/file_system.html#read_directory"},{"doc":"midas/node/file_system","title":"read_directory_content","content":"pub fn read_directory_content(\n  dir: String,\n) -&gt; Result(List(#(String, BitArray)), Snag)\n\nSynonyms:\nmidas/node/file_system.read_directory_content\nmidas/node/file_system read_directory_content","url":"midas/node/file_system.html#read_directory_content"},{"doc":"midas/node/file_system","title":"read_json","content":"pub fn read_json(\n  filename: String,\n  decoder: fn(Dynamic) -&gt; Result(a, List(DecodeError)),\n) -&gt; Result(a, Snag)\n\nSynonyms:\nmidas/node/file_system.read_json\nmidas/node/file_system read_json","url":"midas/node/file_system.html#read_json"},{"doc":"midas/node/file_system","title":"write","content":"pub fn write(\n  filename: String,\n  bytes: BitArray,\n) -&gt; Result(Nil, Snag)\n\nSynonyms:\nmidas/node/file_system.write\nmidas/node/file_system write","url":"midas/node/file_system.html#write"},{"doc":"midas/node/file_system","title":"midas/node/file_system","content":"","url":"midas/node/file_system.html"},{"doc":"midas/node/gleam","title":"build_js","content":"pub fn build_js(root: String) -&gt; Result(String, Snag)\n\nSynonyms:\nmidas/node/gleam.build_js\nmidas/node/gleam build_js","url":"midas/node/gleam.html#build_js"},{"doc":"midas/node/gleam","title":"package_interface","content":"pub fn package_interface(\n  root: String,\n  package: String,\n) -&gt; Result(Package, a)\n\nSynonyms:\nmidas/node/gleam.package_interface\nmidas/node/gleam package_interface","url":"midas/node/gleam.html#package_interface"},{"doc":"midas/node/gleam","title":"midas/node/gleam","content":"","url":"midas/node/gleam.html"},{"doc":"midas/node/rollup","title":"bundle_fn","content":"pub fn bundle_fn(\n  root: String,\n  file: String,\n  func: String,\n) -&gt; Promise(Result(String, Snag))\n\nSynonyms:\nmidas/node/rollup.bundle_fn\nmidas/node/rollup bundle_fn","url":"midas/node/rollup.html#bundle_fn"},{"doc":"midas/node/rollup","title":"iife","content":"pub fn iife(input: String) -&gt; Promise(Result(String, Dynamic))\n\nSynonyms:\nmidas/node/rollup.iife\nmidas/node/rollup iife","url":"midas/node/rollup.html#iife"},{"doc":"midas/node/rollup","title":"midas/node/rollup","content":"","url":"midas/node/rollup.html"},{"doc":"midas/node/zip","title":"zip","content":"pub fn zip(files: List(#(String, BitArray))) -&gt; Promise(BitArray)\n\nSynonyms:\nmidas/node/zip.zip\nmidas/node/zip zip","url":"midas/node/zip.html#zip"},{"doc":"midas/node/zip","title":"midas/node/zip","content":"","url":"midas/node/zip.html"},{"doc":"midas/node","title":"do_fetch","content":"pub fn do_fetch(\n  request: Request(BitArray),\n) -&gt; Promise(Result(Response(BitArray), FetchError))\n\nSynonyms:\nmidas/node.do_fetch\nmidas/node do_fetch","url":"midas/node.html#do_fetch"},{"doc":"midas/node","title":"run","content":"pub fn run(\n  task: Effect(a),\n  root: String,\n) -&gt; Promise(Result(a, Snag))\n\nSynonyms:\nmidas/node.run\nmidas/node run","url":"midas/node.html#run"},{"doc":"midas/node","title":"watch","content":"pub fn watch(\n  task: Effect(a),\n  root: String,\n  callback: fn(Result(a, Snag)) -&gt; Nil,\n) -&gt; Promise(Nil)\n\nSynonyms:\nmidas/node.watch\nmidas/node watch","url":"midas/node.html#watch"},{"doc":"midas/node","title":"midas/node","content":"","url":"midas/node.html"},{"doc":"midas/node/http","title":"read_json","content":"pub fn read_json(\n  response: Response(FetchBody),\n) -&gt; Promise(Result(Response(Dynamic), Snag))\n\nSynonyms:\nmidas/node/http.read_json\nmidas/node/http read_json","url":"midas/node/http.html#read_json"},{"doc":"midas/node/http","title":"read_text","content":"pub fn read_text(\n  response: Response(FetchBody),\n) -&gt; Promise(Result(Response(String), Snag))\n\nSynonyms:\nmidas/node/http.read_text\nmidas/node/http read_text","url":"midas/node/http.html#read_text"},{"doc":"midas/node/http","title":"send","content":"pub fn send(\n  request: Request(String),\n) -&gt; Promise(Result(Response(FetchBody), Snag))\n\nSynonyms:\nmidas/node/http.send\nmidas/node/http send","url":"midas/node/http.html#send"},{"doc":"midas/node/http","title":"midas/node/http","content":"","url":"midas/node/http.html"}]);